@@ -12,23 +12,28 @@ if (!isGeneric("addLayer")) {
 setMethod('addLayer', signature(x='Raster'), 
 function(x, ...) {
 
+	rasters <- .makeRasterList(...)
+
 	if (! inherits(x, 'RasterStack')) {
 		x <- stack(x)
 	}
 
-	rasters <- .makeRasterList(...)
 	if (length(rasters)==0) { 
 		return(x) 
 	}
 
-	compare(rasters) 
+	if (nlayers(x) > 0) {
+		compare(c(x, rasters))
+	} else if (length(rasters) > 1) {
+		compare(rasters)
+	}
 		
 	vals <- sapply(rasters, hasValues) 
 	if (sum(vals) == 0 &  nlayers(x) == 0) { 
 		vals[1] <- TRUE 
 	}
 	if (sum(vals) != length(vals)) { 
-		warning('Cannot add RasterLayer with no associated data in memory or on disk to a RasterStack')
+		warning('Cannot add a RasterLayer with no associated data in memory or on disk to a RasterStack')
 	}
 	rasters <- rasters[vals]
 	
